@@ -1,14 +1,13 @@
 package ZMQ::FFI::ZMQ2::Socket;
-{
-  $ZMQ::FFI::ZMQ2::Socket::VERSION = '0.15';
-}
-
+$ZMQ::FFI::ZMQ2::Socket::VERSION = '0.16';
 use Moo;
 use namespace::autoclean;
 
 use Carp;
 use FFI::Raw;
 
+use ZMQ::FFI::Constants q(zmq_msg_t_size);
+
 extends q(ZMQ::FFI::SocketBase);
 
 has _zmq2_ffi => (
@@ -36,7 +35,7 @@ sub send {
     my $bytes      = pack "a$bytes_size", $msg;
     my $bytes_ptr  = unpack('L!', pack('P', $bytes));
 
-    my $msg_ptr = FFI::Raw::memptr(40); # large enough to hold zmq_msg_t
+    my $msg_ptr = FFI::Raw::memptr(zmq_msg_t_size);
 
     $self->check_error(
         'zmq_msg_init_size',
@@ -62,7 +61,7 @@ sub recv {
 
     $flags //= 0;
 
-    my $msg_ptr = FFI::Raw::memptr(40);
+    my $msg_ptr = FFI::Raw::memptr(zmq_msg_t_size);
 
     $self->check_error(
         'zmq_msg_init',
@@ -141,13 +140,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 ZMQ::FFI::ZMQ2::Socket
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 AUTHOR
 
